@@ -15,10 +15,25 @@
 #' points(cania.sub.ts$Date, res, type="l", col="blue")
 
 bf_oneparam <- function(discharge, k){
-    bf <- rep(discharge[1],length(discharge))
-    for(i in 2:length(discharge)) {
-        bf[i] <- (k*bf[i-1]/(2-k)) + ((1-k)*discharge[i]/(2-k))
-        if(bf[i] > discharge[i]) bf[i] <- discharge[i]
+    # Remove NA values and store the indices
+    na_indices <- is.na(discharge)
+    discharge_sub <- discharge[!na_indices]
+    
+    # Pre-allocate the output vector
+    bf <- numeric(length(discharge_sub))
+    
+    # Initialize the first value
+    bf[1] <- discharge_sub[1]
+    
+    # Calculate the base flow using vectorized operations
+    for (i in 2:length(discharge_sub)) {
+        bf[i] <- (k * bf[i-1] / (2 - k)) + ((1 - k) * discharge_sub[i] / (2 - k))
+        if (bf[i] > discharge_sub[i]) bf[i] <- discharge_sub[i]
     }
-    return(bf)
+    
+    # Create the final output vector with NAs in the original positions
+    bf_out <- rep(NA, length(discharge))
+    bf_out[!na_indices] <- bf
+    
+    return(bf_out)
 }
\ No newline at end of file
